#######################################################################
#
#    ExecuteOnPowerEvent for Enigma-2
#    Coded by StarStb (c) 2013 <starckjohann(at)googlemail.com>
#    Support: http://www.dreambox-tools.info
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#######################################################################

from Components.ActionMap import ActionMap
from Components.config import config, ConfigSubsection, ConfigYesNo, ConfigText, getConfigListEntry
from Components.ConfigList import ConfigListScreen
from Components.Sources.StaticText import StaticText
from enigma import eConsoleAppContainer
from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from Screens.Setup import SetupSummary
from Screens.Standby import Standby
from Tools import Notifications
from twisted.web.client import getPage,downloadPage

config.plugins.ExecuteOnPowerEvent = ConfigSubsection()
config.plugins.ExecuteOnPowerEvent.enabled = ConfigYesNo(default = True)
config.plugins.ExecuteOnPowerEvent.sendurl = ConfigYesNo(default = True)
config.plugins.ExecuteOnPowerEvent.OnUrl = ConfigText(default = "http://192.168.178.1:80/plug-on.php", visible_width = 55, fixed_size = False)
config.plugins.ExecuteOnPowerEvent.OffUrl = ConfigText(default = "http://192.168.178.1:80/plug-off.php", visible_width = 55, fixed_size = False)
config.plugins.ExecuteOnPowerEvent.OnScript = ConfigText(default = "/usr/script/enigma_standby_on.sh", visible_width = 55, fixed_size = False)
config.plugins.ExecuteOnPowerEvent.OffScript = ConfigText(default = "/usr/script/enigma_standby_off.sh", visible_width = 55, fixed_size = False)

class ExecuteOnPowerEvent(object):
	session = None

	def __init__(self):
		config.misc.standbyCounter.addNotifier(self._onStandby, initial_call = False)
		
	def powerOn(self):
		if config.plugins.ExecuteOnPowerEvent.enabled.value:
			if config.plugins.ExecuteOnPowerEvent.sendurl.value:
				print "[Execute on PowerEvent] open URL", config.plugins.ExecuteOnPowerEvent.OnUrl.value
				getPage(config.plugins.ExecuteOnPowerEvent.OnUrl.value)
			else:
				print "[Execute on PowerEvent] execute Script", config.plugins.ExecuteOnPowerEvent.OnScript.value
				self.container = eConsoleAppContainer()
  				self.container.execute(config.plugins.ExecuteOnPowerEvent.OnScript.value)

	def powerOff(self):
		if config.plugins.ExecuteOnPowerEvent.enabled.value:
			if config.plugins.ExecuteOnPowerEvent.sendurl.value:
				print "[Execute on PowerEvent] open URL", config.plugins.ExecuteOnPowerEvent.OffUrl.value
				getPage(config.plugins.ExecuteOnPowerEvent.OffUrl.value)
			else:
				print "[Execute on PowerEvent] execute Script", config.plugins.ExecuteOnPowerEvent.OffScript.value
				self.container = eConsoleAppContainer()
  				self.container.execute(config.plugins.ExecuteOnPowerEvent.OffScript.value)
   				
	def _onStandby(self, element):
		if config.plugins.ExecuteOnPowerEvent.enabled.value:
			from Screens.Standby import inStandby
			inStandby.onClose.append(self.powerOn)
			if config.plugins.ExecuteOnPowerEvent.sendurl.value:
				print "[Execute on PowerEvent] open URL", config.plugins.ExecuteOnPowerEvent.OffUrl.value
				getPage(config.plugins.ExecuteOnPowerEvent.OffUrl.value)
			else:
				print "[Execute on PowerEvent] execute Script", config.plugins.ExecuteOnPowerEvent.OffScript.value
				self.container = eConsoleAppContainer()
				self.container.execute(config.plugins.ExecuteOnPowerEvent.OffScript.value)

ExecuteOnPowerEvent = ExecuteOnPowerEvent()

class ExecuteOnPowerEventConfig(Screen, ConfigListScreen):

	def __init__(self, session):
		Screen.__init__(self, session)
		self.skinName = [ "ExecuteOnPowerEventConfig", "Setup" ]
		self.setup_title = _("ExecuteOnPowerEvent Configuration")

		self.onChangedEntry = []
		self.list = []		
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changedEntry)
		
		self["actions"] = ActionMap(["SetupActions"],
			{
				"cancel": self.keyCancel,
				"save": self.keySave,
			}		)

		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("OK"))
		
		self.buildConfig()

		self.onLayoutFinish.append(self.layoutFinished)		

	def layoutFinished(self):
		self.setTitle(self.setup_title)		
		
	def buildConfig(self):	
		self.list = [ getConfigListEntry(_("Execute on PowerEvent enable:"), config.plugins.ExecuteOnPowerEvent.enabled) ]
		if config.plugins.ExecuteOnPowerEvent.enabled.value and config.plugins.ExecuteOnPowerEvent.sendurl.value:
			self.list.extend((
				getConfigListEntry(_("Use URL instead of Script:"), config.plugins.ExecuteOnPowerEvent.sendurl),
				getConfigListEntry(_("Power/Standby-On-URL:"), config.plugins.ExecuteOnPowerEvent.OnUrl),
				getConfigListEntry(_("Power/Standby-Off-URL:"), config.plugins.ExecuteOnPowerEvent.OffUrl)
			))
		elif config.plugins.ExecuteOnPowerEvent.enabled.value:
			self.list.extend((	
				getConfigListEntry(_("Use URL instead of Script:"), config.plugins.ExecuteOnPowerEvent.sendurl),		
				getConfigListEntry(_("Power/Standby-On-Script:"), config.plugins.ExecuteOnPowerEvent.OnScript),
				getConfigListEntry(_("Power/Standby-Off-Script:"), config.plugins.ExecuteOnPowerEvent.OffScript)
			))
			
		self["config"].list = self.list
		self["config"].setList(self.list)	

	def keyLeft(self):
		ConfigListScreen.keyLeft(self)
		if self["config"].getCurrent()[1] == config.plugins.ExecuteOnPowerEvent.enabled:
			self.buildConfig()
		elif self["config"].getCurrent()[1] == config.plugins.ExecuteOnPowerEvent.sendurl:
			self.buildConfig()
			
	def keyRight(self):
		ConfigListScreen.keyRight(self)
		if self["config"].getCurrent()[1] == config.plugins.ExecuteOnPowerEvent.enabled:
			self.buildConfig()
		elif self["config"].getCurrent()[1] == config.plugins.ExecuteOnPowerEvent.sendurl:
			self.buildConfig()
			
	def changedEntry(self):
		for x in self.onChangedEntry:
			x()

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		return SetupSummary

def autostart(reason, **kwargs):
	session = kwargs.get('session', None)
	if session is not None:
		ExecuteOnPowerEvent.session = session
	if reason == 0:
		if session is not None:
			if not session.nav.wasTimerWakeup() or session.nav.RecordTimer.getNextRecordingTime() > session.nav.RecordTimer.getNextZapTime():
				ExecuteOnPowerEvent.powerOn()
	else:
		ExecuteOnPowerEvent.powerOff()

def main(session, **kwargs):
	print "[Execute on PowerEvent] Open Config Screen"
	session.open(ExecuteOnPowerEventConfig)
	
def Plugins(**kwargs):
	return [
		PluginDescriptor(where = [PluginDescriptor.WHERE_SESSIONSTART, PluginDescriptor.WHERE_AUTOSTART] , fnc = autostart),
		PluginDescriptor(name = "Execute on PowerEvent", description = "Executes a Script or opens an URL on power events", where = PluginDescriptor.WHERE_PLUGINMENU, needsRestart=True, fnc=main)
		]